@@ -10,14 +10,20 @@ class FastTextInput(_BkTextInput):
         help="""Determines the appearance of the textinput. One of `outline` or `filled`.
         Defaults to outlined""",
     )
-    autofocus = properties.Bool(help="""The autofocus attribute. Defaults to `False`""",)
+    autofocus = properties.Bool(
+        help="""The autofocus attribute. Defaults to `False`""",
+    )
     type_of_text = properties.String(
         help="""Determines the type of text accepted. One of `email`, `password`, `tel`, `text` or `url`.
         Defaults to text.
         """
     )
-    max_length = properties.Int(help="""The maximum length of the text string""",)
-    min_length = properties.Int(help="""The minimum length of the text string""",)
+    max_length = properties.Int(
+        help="""The maximum length of the text string""",
+    )
+    min_length = properties.Int(
+        help="""The minimum length of the text string""",
+    )
     pattern = properties.String(
         help="""A regular expression that the input's value must match in order for the value to pass constraint validation"""
     )
